@@ -44,6 +44,7 @@ from zope.deprecation import deprecate
 from zope.i18nmessageid import MessageFactory
 
 import Globals
+import urllib
 
 
 pl_message = MessageFactory("plonelocales")
@@ -478,15 +479,15 @@ class WebHelpers(BrowserView):
 
     @property
     def came_from_param(self):
-        param = ''
         if self.came_from:
+            # If the tool has a notification message, we cannot allow to deeplink
+            # into it, since the user might then miss the notificaton.
+            if not self.tool_notification():
+                return urllib.urlencode({"came_from": self.came_from})
             survey_url = self.survey_url()
             if survey_url:
-                param = 'came_from={0}'.format(survey_url)
-            else:
-                param = 'came_from={0}'.format(self.came_from)
-
-        return param
+                return urllib.urlencode({"came_from": survey_url})
+        return ""
 
     @property
     @memoize
@@ -685,7 +686,7 @@ class WebHelpers(BrowserView):
 
     def tool_notification(self):
         message = None
-        obj = self.context
+        obj = self._survey
         if isinstance(obj, PathGhost):
             obj = self.context.aq_parent
         if ISurvey.providedBy(obj) and obj.hasNotification():
