@@ -1,25 +1,34 @@
-from zope.component import adapts
-from zope.interface import implements
-from zope.interface import Interface
-from zope.interface import directlyProvidedBy
-from zope.interface import directlyProvides
-from zope.publisher.interfaces.browser import IBrowserSkinType
-from ZPublisher.BaseRequest import DefaultPublishTraverse
-from five import grok
-from plone.directives import dexterity
-from plone.directives import form
-from plone.app.dexterity.behaviors.metadata import IBasic
+"""
+Client
+------
+
+The view for the frontpage of the client site and some adapters to provide a
+client user.
+"""
+
 from borg.localrole.interfaces import ILocalRoleProvider
 from euphorie.client.interfaces import IClientSkinLayer
-from euphorie.client.api.entry import access_api
+from five import grok
+from plone.app.dexterity.behaviors.metadata import IBasic
+from plone.directives import dexterity
+from plone.directives import form
 from Products.membrane.interfaces.user import IMembraneUserObject
+from zope.component import adapts
+from zope.interface import directlyProvidedBy
+from zope.interface import directlyProvides
+from zope.interface import implements
+from zope.interface import Interface
+from zope.publisher.interfaces.browser import IBrowserSkinType
+from ZPublisher.BaseRequest import DefaultPublishTraverse
+
 
 class IClient(form.Schema, IBasic):
     """The online client.
 
     The online client is implemented as a container with all available surveys.
     The default view for all survey elements inside this container is changed
-    to the client user interface. This is done using a simple traversal adapter.
+    to the client user interface. This is done using a simple traversal
+    adapter.
     """
 
 
@@ -29,21 +38,6 @@ class Client(dexterity.Container):
     exclude_from_nav = True
 
 
-grok.templatedir("templates")
-
-
-class View(grok.View):
-    grok.context(IClient)
-    grok.require("zope2.View")
-    grok.layer(IClientSkinLayer)
-    grok.template("frontpage")
-
-    def update(self):
-        self.enabled_countries=frozenset(self.context.keys())
-
-
-
-
 class ClientUserProvider(grok.Adapter):
     """Expose the client as a user to the system.
 
@@ -59,7 +53,6 @@ class ClientUserProvider(grok.Adapter):
         return self.context.id
 
 
-
 class ClientLocalRolesProvider(grok.Adapter):
     """`borg.localrole` provider for :obj:`IClient` instances.
 
@@ -72,10 +65,10 @@ class ClientLocalRolesProvider(grok.Adapter):
     grok.implements(ILocalRoleProvider)
 
     def __init__(self, client):
-        self.context=client
+        self.context = client
 
     def getRoles(self, principal_id):
-        if principal_id==self.context.getId():
+        if principal_id == self.context.getId():
             return ("CountryManager",)
         return ()
 
@@ -83,7 +76,6 @@ class ClientLocalRolesProvider(grok.Adapter):
         return [(self.context.getId(), ("CountryManager",))]
 
 
-
 class ClientPublishTraverser(DefaultPublishTraverse):
     """Publish traverser to setup the skin layer.
 
@@ -95,12 +87,10 @@ class ClientPublishTraverser(DefaultPublishTraverse):
     def publishTraverse(self, request, name):
         from euphorie.client.utils import setRequest
         setRequest(request)
-        request.client = self.context
-
-        if name == 'api':
-            return access_api(request).__of__(self.context)
+        request.client = self.context  # XXX: remove me
 
         ifaces = [iface for iface in directlyProvidedBy(request)
                 if not IBrowserSkinType.providedBy(iface)]
         directlyProvides(request, IClientSkinLayer, ifaces)
-        return super(ClientPublishTraverser, self).publishTraverse(request, name)
+        return super(ClientPublishTraverser, self)\
+                .publishTraverse(request, name)
